about summary refs log tree commit diff
path: root/tvix/eval/src
diff options
context:
space:
mode:
authorFlorian Klink <flokli@flokli.de>2024-02-21T13·39+0700
committerflokli <flokli@flokli.de>2024-02-21T13·55+0000
commit771200df7c311fc8b87a0a65a02e22a11d80cd66 (patch)
tree313d820dbfc9839098cd33238092819a1cc434a8 /tvix/eval/src
parent3e93efdc8cb3c6cefaedf8f9f11f1f3f697d079e (diff)
fix(tvix/eval): allow reading non-UTF8 files r/7587
With our values using bstr now, we're not restricted to only reading
files that contain valid UTF-8.

Update our `read_to_string` function to `read_to_end`
(named like `std::io::Read::read_to_end`), and have it return a Vec<u8>.

Change-Id: I87f0291dc855a132689576559c891d66c30ddf2b
Reviewed-on: https://cl.tvl.fyi/c/depot/+/11003
Tested-by: BuildkiteCI
Autosubmit: flokli <flokli@flokli.de>
Reviewed-by: Pádraic Ó Mhuiris <patrick.morris.310@gmail.com>
Reviewed-by: flokli <flokli@flokli.de>
Diffstat (limited to 'tvix/eval/src')
-rw-r--r--tvix/eval/src/io.rs10
-rw-r--r--tvix/eval/src/vm/generators.rs2
2 files changed, 6 insertions, 6 deletions
diff --git a/tvix/eval/src/vm/generators.rs b/tvix/eval/src/vm/generators.rs
index fba4e7cd90..2a2710dc34 100644
--- a/tvix/eval/src/vm/generators.rs
+++ b/tvix/eval/src/vm/generators.rs
@@ -429,7 +429,7 @@ where
                             let content = self
                                 .io_handle
                                 .as_ref()
-                                .read_to_string(&path)
+                                .read_to_end(&path)
                                 .map_err(|e| ErrorKind::IO {
                                     path: Some(path),
                                     error: e.into(),
diff --git a/tvix/eval/src/io.rs b/tvix/eval/src/io.rs
index ccbc7dfdbc..6589c0dc5c 100644
--- a/tvix/eval/src/io.rs
+++ b/tvix/eval/src/io.rs
@@ -48,13 +48,13 @@ pub trait EvalIO {
     /// * `builtins.pathExists :: path -> bool`
     fn path_exists(&self, path: &Path) -> io::Result<bool>;
 
     /// Read the file at the specified path to a string.
     ///
     /// This is used for the following language evaluation cases:
     ///
     /// * `builtins.readFile :: path -> string`
     /// * `builtins.import :: path -> any`
-    fn read_to_string(&self, path: &Path) -> io::Result<String>;
+    fn read_to_end(&self, path: &Path) -> io::Result<Vec<u8>>;
 
     /// Read the directory at the specified path and return the names
     /// of its entries associated with their [`FileType`].
@@ -99,8 +99,8 @@ impl EvalIO for StdIO {
         path.try_exists()
     }
 
-    fn read_to_string(&self, path: &Path) -> io::Result<String> {
-        std::fs::read_to_string(path)
+    fn read_to_end(&self, path: &Path) -> io::Result<Vec<u8>> {
+        std::fs::read(path)
     }
 
     fn read_dir(&self, path: &Path) -> io::Result<Vec<(bytes::Bytes, FileType)>> {
@@ -145,7 +145,7 @@ impl EvalIO for DummyIO {
         ))
     }
 
-    fn read_to_string(&self, _: &Path) -> io::Result<String> {
+    fn read_to_end(&self, _: &Path) -> io::Result<Vec<u8>> {
         Err(io::Error::new(
             io::ErrorKind::Unsupported,
             "I/O methods are not implemented in DummyIO",
@@ -48,13 +48,13 @@ pub trait EvalIO {
     fn path_exists(&self, path: &Path) -> io::Result<bool>;
 
-    /// Read the file at the specified path to a string.
+    /// Read the file at the specified path to a Vec<u8>.
     ///
     /// This is used for the following language evaluation cases: